@@ -12,14 +12,26 @@ class TestRepos(unittest.TestCase):
                     "CSTNGL22I10D086I" ]
 
         for cf in invalid:
-            self.assertFalse(isvalid(invalid))
+            self.assertFalse(isvalid(cf))
+        
+        valid = ( 'MRTNTN23M02D969P', 
+                  'RCCMNL83S18D969H', 
+                  'MRSMSR81D60Z611H',
+                  'CNTCHR83T41D969D', 
+                  'FOXDRA26C24H872Y',
+                  'MAILCU91A25F839D' )
+
+        for cf in valid:
+            self.assertTrue(isvalid(cf))
 
     def test_get_birthday(self):
         inputs = { 
             'MRTNTN23M02D969P': '2-8-23',
             'RCCMNL83S18D969H': '18-11-83',
             'MRSMSR81D60Z611H': '20-4-81',
-            'CNTCHR83T41D969D': '1-12-83'
+            'CNTCHR83T41D969D': '1-12-83',
+            'FOXDRA26C24H872Y': '24-3-26',
+            'MAILCU91A25F839D': '25-1-91'
         }
                      
         for cf, expected in inputs.items():
@@ -32,6 +44,8 @@ class TestRepos(unittest.TestCase):
             'RCDLSN84S16D969Z': 'M',
             'MRSMSR81D60Z611H': 'F',
             'CNTCHR83T41D969D': 'F',
+            'FOXDRA26C24H872Y': 'M',
+            'MAILCU91A25F839D': 'M'
         }
                      
         for cf, expected in inputs.items():
@@ -39,12 +53,15 @@ class TestRepos(unittest.TestCase):
 
     def test_control_code(self):
         inputs = { 
+            # fiscal codes tested in this module
             'MRTNTN23M02D969': 'P',
             'MRSMSR81D60Z611': 'H',
             'RCDLSN84S16D969': 'Z',
             'CNTCHR83T41D969': 'D',
             'BNCSFN85T58G702': 'W',
             'RCCMNL83S18D969': 'H',
+            'FOXDRA26C24H872': 'Y',
+            'MAILCU91A25F839': 'D'
         }
 
         for cf, expected in inputs.items():
@@ -75,6 +92,21 @@ class TestRepos(unittest.TestCase):
                 "Arcidiacono", "Alessandro", 
                 datetime.datetime(1984, 11, 16),
                 'M','D969'
+            ),
+
+            'FOXDRA26C24H872Y': ( 
+                "Fo", "Dario", 
+                datetime.datetime(1926, 3, 24),
+                'M',
+                # born in Sangiano
+                'H872'
+            ),
+
+            'MAILCU91A25F839D': (
+                "Maio", "Luca",
+                datetime.datetime(1991, 1, 25),
+                'M',
+                'F839'
             )
         }
         
